@@ -226,7 +226,7 @@ class RestAPI(object):
 
 				# delete.
 				try:
-					r = self.stripe.Subscription.delete(subscription_id)
+					r = self.stripe.Subscription.delete(info["subscription_id"])
 					success = r["status"] == "canceled"
 				except Exception as e: 
 					success = str(e)
